==> popmon-0.3.9.tar.gz: popmon-0.3.9/popmon/analysis/comparison/__init__.py <==
# Copyright (c) 2020 ING Wholesale Banking Advanced Analytics
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


from ...analysis.comparison.hist_comparer import (
    ExpandingHistComparer,
    ExpandingNormHistComparer,
    ReferenceHistComparer,
    ReferenceNormHistComparer,
    RollingHistComparer,
    RollingNormHistComparer,
)

__all__ = [
    "ReferenceHistComparer",
    "RollingHistComparer",
    "ExpandingHistComparer",
    "ReferenceNormHistComparer",
    "RollingNormHistComparer",
    "ExpandingNormHistComparer",
]

==> popmon-1.4.7.tar.gz: popmon-1.4.7/popmon/analysis/comparison/__init__.py <==
# Copyright (c) 2023 ING Analytics Wholesale Banking
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
from popmon.analysis.comparison.hist_comparer import (
    ExpandingHistComparer,
    ExpandingNormHistComparer,
    ReferenceHistComparer,
    ReferenceNormHistComparer,
    RollingHistComparer,
    RollingNormHistComparer,
)

from .comparisons import Comparisons

__all__ = [
    "Comparisons",
    "ReferenceHistComparer",
    "RollingHistComparer",
    "ExpandingHistComparer",
    "ReferenceNormHistComparer",
    "RollingNormHistComparer",
    "ExpandingNormHistComparer",
]
